===============
pyTMD Providers
===============

The main database is created by merging the model provider JSON files

- ``AVISO``: `AVISO Global Ocean Tide Models <https://www.aviso.altimetry.fr/en/data/products/auxiliary-products/global-tide-fes.html>`_
- ``ESR``: `Earth and Space Research Polar Tide Models <https://www.esr.org/research/polar-tide-models/>`_
- ``GSFC``: `NASA Goddard Space Flight Center Global Tide Models <https://earth.gsfc.nasa.gov/geo/data/ocean-tide-models>`_
- ``TPXO``: `Oregon State University TPXO Tide Models <https://www.tpxo.net/home>`_
- ``providers``: Additional or stand-alone model providers
